@@ -581,7 +581,7 @@ CONFIGLOOP: {
 		$C->{ConfigFile} = "$Global::ConfDir/$C->{CatalogName}.before";
 	}
 
-    open(Vend::CONFIG, $C->{ConfigFile})
+    open(Vend::CONFIG, "< $C->{ConfigFile}")
 		or do {
 			my $msg = "Could not open configuration file '" . $C->{ConfigFile} .
 					"' for catalog '" . $catalog . "':\n$!";
@@ -896,7 +896,7 @@ sub global_config {
 	};
 
  GLOBLOOP: {
-    open(Vend::GLOBAL, $configfile)
+    open(Vend::GLOBAL, "< $configfile")
 		or die "Could not open configuration file '" .
                 $configfile . "':\n$!\n";
     while(<Vend::GLOBAL>) {
