@@ -326,8 +326,8 @@ sub compare_file {
     my($first,$second) = @_;
     return 0 unless -s $first == -s $second;
     local $/;
-    open(FIRST, $first) or return undef;
-    open(SECOND, $second) or (close FIRST and return undef);
+    open(FIRST, "< $first") or return undef;
+    open(SECOND, "< $second") or (close FIRST and return undef);
     binmode(FIRST);
     binmode(SECOND);
     $first = '';
@@ -383,7 +383,7 @@ sub install_file {
     }
 
     if( ! $Windows and -f $targfile and ! compare_file($srcfile, $targfile) ) {
-        open (GETVER, $targfile)
+        open (GETVER, "< $targfile")
             or die "Couldn't read $targfile for version update: $!\n";
         while(<GETVER>) {
             /VERSION\s+=.*?\s+([\d.]+)/ or next;
@@ -404,7 +404,7 @@ sub install_file {
 	if($opt->{Substitute}) {
 			my $bak = "$targfile.mv";
 			rename $targfile, $bak;
-			open(SOURCE, "$bak")			or die "open $bak: $!\n";
+			open(SOURCE, "< $bak")			or die "open $bak: $!\n";
 			open(TARGET, ">$targfile")		or die "create $targfile: $!\n";
 			local($/) = undef;
 			my $page = <SOURCE>; close SOURCE;
@@ -533,7 +533,7 @@ sub add_catalog {
 		else {
 			File::Copy::copy("$file.dist", $tmpfile);
 		}
-		open(CFG, $tmpfile)
+		open(CFG, "< $tmpfile")
 			or die "Couldn't open $tmpfile: $!\n";
 		$newcfgline = sprintf "%-19s %s\n", $directive, $value;
 		while(<CFG>) {
@@ -565,7 +565,7 @@ sub add_catalog {
 			my $pid;
 			PID: {
 				local ($/);
-				open(PID,$pidfile) or die "open $pidfile: $!\n";
+				open(PID,"< $pidfile") or die "open $pidfile: $!\n";
 				$pid = <PID>;
 				$pid =~ /(\d+)/;
 				$pid = $1;
@@ -617,7 +617,7 @@ sub conf_parse_http {
 	my $servers = {};
 	my $newfile;
 
-	open(HTTPDCONF, $file)
+	open(HTTPDCONF, "< $file")
 		or do { $Error = "Can't open $file: $!"; return undef};
 	local($/) = undef;
 	my $data = <HTTPDCONF>;
@@ -645,7 +645,7 @@ sub conf_parse_http {
 
 	SRMCONF: {
 		if (-f $newfile) {
-			open(HTTPDCONF, $newfile)
+			open(HTTPDCONF, "< $newfile")
 				or last SRMCONF;
 			$data .= <HTTPDCONF>;
 			close(HTTPDCONF);
