@@ -1189,7 +1189,7 @@ sub _find_field {
 
 	if(defined $file) {
 		my $dir = $s->{base_directory} || $Vend::Cfg->{ProductDir};
-		open (Vend::Scan::FIELDS, "$dir/$file")
+		open (Vend::Scan::FIELDS, "< $dir/$file")
 			or return undef;
 		chomp($line = <Vend::Scan::FIELDS>);
 		@fields = split /$Vend::Cfg->{Delimiter}/, $line;
