@@ -251,7 +251,7 @@ sub more_matches {
 	my $file = $g->{save_dir} . '/' . $id if $g->{save_dir};
 
 	if($file) {
-		open(Vend::Search::MORE, $file)
+		open(Vend::Search::MORE, "< $file")
 			or do { $g->{matches} = -1;
 			&{$g->{error_routine}}($g->{error_page}, "couldn't open $file: $!\n");
 			};
