@@ -1,9 +1,9 @@
 # SessionFile.pm:  stores session information in files
 #
-# $Id: SessionFile.pm,v 1.2 1997/06/17 04:22:52 mike Exp $
+# $Id: SessionFile.pm,v 1.7 1998/01/31 05:22:20 mike Exp $
 #
 # Copyright 1996 by Andrew M. Wilcox <awilcox@world.std.com>
-# Copyright 1996 by Michael J. Heins <mikeh@iac.net>
+# Copyright 1996-1998 by Michael J. Heins <mikeh@iac.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 
-# $Id: SessionFile.pm,v 1.2 1997/06/17 04:22:52 mike Exp $
+# $Id: SessionFile.pm,v 1.7 1998/01/31 05:22:20 mike Exp $
 
 package Vend::SessionFile;
 require Tie::Hash;
@@ -29,6 +29,9 @@ require Tie::Hash;
 use strict;
 use Vend::Util;
 
+use vars qw($VERSION);
+$VERSION = substr(q$Revision: 1.7 $, 10);
+
 my $SessionDir;
 my $SessionFile;
 my $SessionLock;
@@ -47,14 +50,21 @@ sub FETCH {
 	my($self, $key) = @_;
     $SessionFile = $SessionDir . "/$key";
     $SessionLock = $SessionDir . "/LOCK_$key";
+	return undef unless -f $SessionFile;
 	my $str;
-    open(SESSIONLOCK, "+>>$SessionLock")
-        or die "Can't open '$SessionLock': $!\n";
-    open(SESSION, "+>>$SessionFile")
-        or die "Can't open '$SessionFile': $!\n";
-    lockfile(\*SESSION, 1, 1);
+	if($Global::Windows) {
+		open SESSION, "< $SessionFile"
+			or return '';
+	}
+	else {
+		open(SESSIONLOCK, "+>>$SessionLock")
+			or die "Can't open '$SessionLock': $!\n";
+		open(SESSION, "+>>$SessionFile")
+			or die "Can't open '$SessionFile': $!\n";
+		lockfile(\*SESSION, 1, 1);
 
-    seek(SESSION, 0, 0) or die "Can't seek session: $!\n";
+		seek(SESSION, 0, 0) or die "Can't seek session: $!\n";
+	}
     while(<SESSION>) {
 		$str .= $_;
 	}
@@ -88,15 +98,24 @@ sub DELETE {
     my $lockname = $SessionDir . "/LOCK_$key";
 	(warn ("SessionFile.pm: $key not found.\n"), return 0) unless -f $filename;
 	unlink $filename or die "Couldn't delete key $key: $!\n";
+	return 1 if $Global::Windows;
 	unlink $lockname or die "Couldn't delete lock for key $key: $!\n";
 }
 
 sub STORE {
 	my($self, $key, $val) = @_;
+    $SessionFile = $SessionDir . "/$key";
+    $SessionLock = $SessionDir . "/LOCK_$key";
 	close(SESSION);
     unlink $SessionFile;
-    open(SESSION, "+>$SessionFile")
-        or die "Can't open '$SessionFile': $!\n";
+	if($Global::Windows) {
+		open SESSION, ">$SessionFile"
+        or die "Can't write '$SessionFile': $!\n";
+	}
+	else {
+		open(SESSION, "+>$SessionFile")
+			or die "Can't open '$SessionFile': $!\n";
+	}
     #seek(SESSION, 0, 0) or die "Can't seek session: $!\n";
     #lockfile(\*SESSION, 1, 1);
 	print SESSION $val;
