@@ -743,7 +743,7 @@ EOF
 			$fn = $try . "/" . escape_chars($file) . $suffix;
 		}
 
-		if (open(Vend::IN, $fn)) {
+		if (open(Vend::IN, "< $fn")) {
 			binmode(Vend::IN) if $Global::Windows;
 			undef $/;
 			$contents = <Vend::IN>;
@@ -795,7 +795,10 @@ sub readfile {
 		return undef;
 	}
 
-    if (open(Vend::IN, $file)) {
+    if (! -f $file) {
+		return undef;
+	}
+    elsif (open(Vend::IN, "< $file")) {
 		binmode(Vend::IN) if $Global::Windows;
 		undef $/;
 		$contents = <Vend::IN>;
